@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -36,7 +36,8 @@ THIS_DIR = os.path.dirname(os.path.realpath(__file__))
 def run_all_unit_tests() -> None:
     cmdargs = [
         # "python", "-m", "unittest", "discover", "-s", THIS_DIR, "-p", "*.py"
-        "pytest", THIS_DIR
+        "pytest",
+        THIS_DIR,
     ]
     subprocess.check_call(cmdargs)
 
