@@ -212,6 +212,7 @@ SQLTYPES_DATETIME_ALL = SQLTYPES_WITH_DATE + SQLTYPES_DATETIME_OTHER
 SQLTYPES_ALL = (
     SQLTYPES_INTEGER
     + SQLTYPES_FLOAT
+    + SQLTYPES_BIT
     + SQLTYPES_OTHER_NUMERIC
     + SQLTYPES_TEXT
     + SQLTYPES_BINARY
@@ -221,11 +222,14 @@ SQLTYPES_ALL = (
 SQLTYPES_NOT_TEXT = (
     SQLTYPES_INTEGER
     + SQLTYPES_FLOAT
+    + SQLTYPES_BIT
     + SQLTYPES_OTHER_NUMERIC
     + SQLTYPES_DATETIME_ALL
     + SQLTYPES_OTHER
 )
-SQLTYPES_NUMERIC = SQLTYPES_INTEGER + SQLTYPES_FLOAT + SQLTYPES_OTHER_NUMERIC
+SQLTYPES_NUMERIC = (
+    SQLTYPES_INTEGER + SQLTYPES_FLOAT + SQLTYPES_BIT + SQLTYPES_OTHER_NUMERIC
+)
 
 
 # =============================================================================
